version 9.2

* This file does the event study for the base-case Geithner nomination event
* This file is run separately for each cabinet member; use appropriate event date below, and adjust number in loop down further
* Output goes into a file "Event Study Output Cabinet.dta"


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


use "Return Data.dta", clear

set more off

reshape long ri, i(index) j(day) string
gen statadate=date(day,"dm20y")
*gen event_date=17857  /* 17857 is Nov 21, 2008: Geithner nomination first leaked  */
*gen event_date=17855  /* 17855 is Nov 19, 2008: Holder nomination first leaked (late on 18th) */
*gen event_date=17883  /* 17883 is Dec 17, 2008: Vilsack nomination first leaked  (after market close on 16th) */
*gen event_date=17952  /* 17952 is Feb 24, 2009: Locke nomination first leaked (late night on 23rd) */
*gen event_date=17877  /* 17877 is Dec 11, 2008: Chu nomination first leaked  */
*gen event_date=17882  /* 17882 is Dec 16, 2008: Duncan nomination first leaked  (appeared to be after market close on 15th)*/
*gen event_date=17874  /* 17874 is Dec 8, 2008: Shinseki nomination first leaked (some news on Sunday the 7th) */
gen event_date=17856  /* 17855 is Nov 20, 2008: Napolitano nomination first leaked (late night on 19th)  */

* drop stock market holidays

drop if statadate==17351 |statadate==17412 |statadate==17492 |statadate==17525 |statadate==17532 |statadate==17552 | statadate==17580 |statadate==17612 | statadate==17678 | statadate==17717 | statadate==17776 | statadate==17863 | statadate==17891 | statadate==17898 | statadate==17916 | statadate==17944 |statadate==17997


* create difference from event date

sort index statadate
by index: gen datenum=_n
by index: gen target=datenum if statadate==event_date
egen td=min(target), by(index)
drop target
gen dif=datenum-td
drop datenum td


* create returns from return index

sort index statadate
by index: gen ret=(ri-ri[_n-1])/ri[_n-1]


* choose event window and estimation window

by index: gen event_window=1 if dif>=0 & dif<=10 & ~(ret==.)
egen count_event_obs=count(event_window), by(index)
by index: gen estimation_window=1 if dif>=-280 & dif<-30 & ~(ret==.)
egen count_est_obs=count(estimation_window), by(index)

drop if count_est_obs<225
drop if count_event_obs<3


* generate market returns

save "Event Study Output Cabinet.dta", replace
keep if index==679 /* assuming appropriate market index is in row after == */
rename ret market_return
keep statadate market_return
sort statadate 
save "Merge.dta", replace
use "Event Study Output Cabinet.dta", clear
sort statadate 
merge statadate using "Merge.dta"
drop if _merge==2
drop _merge
erase "Merge.dta"

* this puts in the 3pm to 4pm returns for Nov. 21

sort ticker
merge ticker using "Return Nov. 21 Data.dta"
drop if _merge==2
drop _merge


* calculate predicted returns

gen predicted_return=.
egen id=group(index)

* Enter in row below: 666 for Holder, 670 for Vilsack, 673 for Locke, 669 for Chu, 669 for Duncan, 668 for Shinseki, 667 for Napolitano

forvalues i=1(1)667 {
 reg ret market_return if id==`i' & estimation_window==1
 predict p if id==`i'
 replace predicted_return = p if id==`i' & event_window==1
 drop p
}


* calculate abnormal returns

sort index statadate
gen abnormal_return=ret-predicted_return if event_window==1
replace abnormal_return=0 if abnormal_return==.
gen abnormal_return_temp=abnormal_return
by index: egen CAR0to10 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==10
by index: egen CAR0to9 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==9
by index: egen CAR0to8 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==8
by index: egen CAR0to7 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==7
by index: egen CAR0to6 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==6
by index: egen CAR0to5 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==5
by index: egen CAR0to4 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==4
by index: egen CAR0to3 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==3
by index: egen CAR0to2 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==2
by index: egen CAR0to1 = sum(abnormal_return_temp)
drop abnormal_return_temp


* prepare output for merging with master file

drop if event_window==.
drop  event_window count_event_obs estimation_window count_est_obs market_return predicted_return id ri event_date
rename index index_ds
label var index_ds "Index from Datastream download, BANKS.LLT"
rename day date_ds
drop statadate

reshape wide date_ds ret abnormal_return, i(index_ds) j(dif)
sort index
drop in l



save "Event Study Output Cabinet.dta", replace
