version 9.2

* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".

* Panel A
* create list of Geithner-connected firms (schedule), ordered by size

local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


* merge in schedule connections data

use "Schedule Data.dta", clear
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule
save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City

keep  name  geithnerschednum  CAR0to10  ta2008
drop if geithnerschednum==0
order name  geithnerschednum CAR0to10 ta2008
gsort -ta2008
list

* create list of same number of largest non-connected firms (schedule), ordered by size


* merge in schedule connections data

use "Schedule Data.dta", clear
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule
save "Master Data.dta", replace



* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City

keep  name  geithnerschednum  CAR0to10  ta2008
count if geithnerschednum>0
gen numfirms=r(N)
drop if geithnerschednum>0
drop geithnerschednum
order name CAR0to10 ta2008
egen rankta=rank(1/ta2008)
drop if rankta>numfirms
drop rankta numfirms
gsort -ta2008
list


* Panel B
* create list of Geithner-connected firms (personal), ordered by size

* start with personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
label var ny "dummy=1 if addresscity_ds is New York City

keep  name  geithner2num  CAR0to10  ta2008
drop if geithner2num==0
order name  geithner2num CAR0to10 ta2008
gsort -ta2008
list

* create list of same number of largest non-connected firms (personal), ordered by size"

* start with personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 



* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"

label var ny "dummy=1 if addresscity_ds is New York City

keep  name  geithner2num  CAR0to10  ta2008
count if geithner2num>0
gen numfirms=r(N)
drop if geithner2num>0
drop geithner2num
order name CAR0to10 ta2008
egen rankta=rank(1/ta2008)
drop if rankta>numfirms
drop rankta numfirms
gsort -ta2008
list

erase "Master Data.dta"

